package javax.swing.undo;

import javax.swing.UIManager;
import java.io.Serializable;

public class AbstractUndoableEdit implements UndoableEdit, Serializable
{
    protected static final String UndoName = "Undo";
    protected static final String RedoName = "Redo";
    boolean hasBeenDone;
    boolean alive;
    
    public AbstractUndoableEdit() {
        this.hasBeenDone = true;
        this.alive = true;
    }
    
    @Override
    public void die() {
        this.alive = false;
    }
    
    @Override
    public void undo() throws CannotUndoException {
        if (!this.canUndo()) {
            throw new CannotUndoException();
        }
        this.hasBeenDone = false;
        return;
    }
    
    @Override
    public boolean canUndo() {
        return this.alive && this.hasBeenDone;
    }
    
    @Override
    public void redo() throws CannotRedoException {
        if (!this.canRedo()) {
            throw new CannotRedoException();
        }
        this.hasBeenDone = true;
        return;
    }
    
    @Override
    public boolean canRedo() {
        return this.alive && !this.hasBeenDone;
    }
    
    @Override
    public boolean addEdit(UndoableEdit undoableEdit) {
        return false;
    }
    
    @Override
    public boolean replaceEdit(UndoableEdit undoableEdit) {
        return false;
    }
    
    @Override
    public boolean isSignificant() {
        return true;
    }
    
    @Override
    public String getPresentationName() {
        return "";
    }
    
    @Override
    public String getUndoPresentationName() {
        String presentationName = this.getPresentationName();
        if (!"".equals(presentationName)) {
            return UIManager.getString("AbstractUndoableEdit.undoText") + " " + presentationName;
        }
        return UIManager.getString("AbstractUndoableEdit.undoText");
    }
    
    @Override
    public String getRedoPresentationName() {
        String presentationName = this.getPresentationName();
        if (!"".equals(presentationName)) {
            return UIManager.getString("AbstractUndoableEdit.redoText") + " " + presentationName;
        }
        return UIManager.getString("AbstractUndoableEdit.redoText");
    }
    
    @Override
    public String toString() {
        return super.toString() + " hasBeenDone: " + this.hasBeenDone + " alive: " + this.alive;
    }
}
